@@ -1,4 +1,5 @@
 use docker_command::*;
+use std::collections::BTreeMap;
 use std::path::{Path, PathBuf};
 
 fn new_path(s: &str) -> PathBuf {
@@ -7,15 +8,22 @@ fn new_path(s: &str) -> PathBuf {
 
 #[test]
 fn test_build() {
+    let mut build_args = BTreeMap::new();
+    build_args.insert("barg1".into(), "bval1".into());
+    build_args.insert("barg2".into(), "bval2".into());
     assert_eq!(
         Docker::new()
             .build(BuildOpt {
+                build_args,
                 context: new_path("/myContext"),
                 dockerfile: Some(new_path("/myContext/myDockerfile")),
+                no_cache: true,
+                pull: true,
+                quiet: true,
                 tag: Some("myTag".into()),
             })
             .command_line_lossy(),
-        "docker build --file /myContext/myDockerfile --tag myTag /myContext"
+        "docker build --build-arg barg1=bval1 --build-arg barg2=bval2 --file /myContext/myDockerfile --no-cache --pull --quiet --tag myTag /myContext"
     );
 }
 
@@ -96,6 +104,5 @@ fn test_readme_example() {
     let example = example.join("\n");
 
     let readme = include_str!("../README.md");
-    dbg!(&example);
     assert!(readme.contains(&example));
 }
